      SUBROUTINE HELP ( LIBR, STRING, ERROR )
C*
C*                  *******************************
C*                  *******************************
C*                  **                           **
C*                  **          HELP             **
C*                  **                           **
C*                  *******************************
C*                  *******************************
C*
C*     SUBPROGRAM :
C*          HELP
C*
C*     AUTHOR :
C*          ART RAGOSTA
C*          MS 207-5
C*          AMES RESEARCH CENTER
C*          MOFFETT FIELD, CA  94035
C*          (415) 694-5578
C*
C*     PURPOSE :
C*          TO INTERFACE WITH A VMS-FORMAT HELP FILE
C*          FROM WITHIN A FORTRAN PROGRAM.
C*
C*     METHODOLOGY :
C*          CALL THE SYSTEM-SPECIFIC ROUTINE, LBR$OUTPUT_HELP
C*
C*     INPUT ARGUMENTS :
C*          LIBR  - THE NAME OF THE LIBRARY HELP FILE TO BE SEARCHED.
C*          STRING - THE PARAMETER TO THE HELP COMMAND.
C*
C*     OUTPUT ARGUMENTS :
C*          ERROR - A BOOLEAN FLAG WHISH IS SET TRUE IF THERE WAS TROUBLE
C*                   COMPLETING THE REQUEST.
C*
C*     INTERNAL WORK AREAS :
C*          NONE
C*
C*     COMMON BLOCKS :
C*          NONE
C*
C*     FILE REFERENCES :
C*          NONE
C*
C*     DATA BASE ACCESS :
C*          NONE
C*
C*     SUBPROGRAM REFERENCES :
C*          LBR$OUTPUT_HELP, LIB$PUT_OUTPUT, LIB$GET_OUTPUT
C*
C*     ERROR PROCESSING :
C*          CHECK THE STATUS RETURNED BY LBR$OUTPUT_HELP
C*
C*     TRANSPORTABILITY LIMITATIONS :
C*          USES VMS-SPECIFIC ROUTINES.
C*
C*     ASSUMPTIONS AND RESTRICTIONS :
C*          NONE
C*
C*     LANGUAGE AND COMPILER :
C*          ANSI FORTRAN 77
C*
C*     VERSION AND DATE :
C*          VERSION I.0     12-SEP-84
C*
C*     CHANGE HISTORY :
C*          12-SEP-84    INITIAL VERSION
C*
C***********************************************************************
C*
      EXTERNAL LIB$PUT_OUTPUT, LIB$GET_INPUT
      CHARACTER *(*) STRING, LIBR
      LOGICAL ERROR
      EXTERNAL SS$_NORMAL
C
      ISTAT = LBR$OUTPUT_HELP(LIB$PUT_OUTPUT,,STRING,LIBR,,
     $         LIB$GET_INPUT)
      ERROR = ISTAT .NE. %LOC(SS$_NORMAL)
      RETURN
      END
C
C---END HELP
C
